/****************************************************************************
** Meta object code from reading C++ file 'properties.h'
**
** Created by: The Qt Meta Object Compiler version 67 (Qt 5.15.8)
**
** WARNING! All changes made in this file will be lost!
*****************************************************************************/

#include <memory>
#include "../../../src/libtiled/properties.h"
#include <QtCore/qbytearray.h>
#include <QtCore/qmetatype.h>
#if !defined(Q_MOC_OUTPUT_REVISION)
#error "The header file 'properties.h' doesn't include <QObject>."
#elif Q_MOC_OUTPUT_REVISION != 67
#error "This file was generated using the moc from 5.15.8. It"
#error "cannot be used with the include files from this version of Qt."
#error "(The moc has changed too much.)"
#endif

QT_BEGIN_MOC_NAMESPACE
QT_WARNING_PUSH
QT_WARNING_DISABLE_DEPRECATED
struct qt_meta_stringdata_Tiled__PropertyValue_t {
    QByteArrayData data[4];
    char stringdata0[43];
};
#define QT_MOC_LITERAL(idx, ofs, len) \
    Q_STATIC_BYTE_ARRAY_DATA_HEADER_INITIALIZER_WITH_OFFSET(len, \
    qptrdiff(offsetof(qt_meta_stringdata_Tiled__PropertyValue_t, stringdata0) + ofs \
        - idx * sizeof(QByteArrayData)) \
    )
static const qt_meta_stringdata_Tiled__PropertyValue_t qt_meta_stringdata_Tiled__PropertyValue = {
    {
QT_MOC_LITERAL(0, 0, 20), // "Tiled::PropertyValue"
QT_MOC_LITERAL(1, 21, 5), // "value"
QT_MOC_LITERAL(2, 27, 6), // "typeId"
QT_MOC_LITERAL(3, 34, 8) // "typeName"

    },
    "Tiled::PropertyValue\0value\0typeId\0"
    "typeName"
};
#undef QT_MOC_LITERAL

static const uint qt_meta_data_Tiled__PropertyValue[] = {

 // content:
       8,       // revision
       0,       // classname
       0,    0, // classinfo
       0,    0, // methods
       3,   14, // properties
       0,    0, // enums/sets
       0,    0, // constructors
       4,       // flags
       0,       // signalCount

 // properties: name, type, flags
       1, QMetaType::QVariant, 0x00095003,
       2, QMetaType::Int, 0x00095003,
       3, QMetaType::QString, 0x00095001,

       0        // eod
};

void Tiled::PropertyValue::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{

#ifndef QT_NO_PROPERTIES
    if (_c == QMetaObject::ReadProperty) {
        auto *_t = reinterpret_cast<PropertyValue *>(_o);
        (void)_t;
        void *_v = _a[0];
        switch (_id) {
        case 0: *reinterpret_cast< QVariant*>(_v) = _t->value; break;
        case 1: *reinterpret_cast< int*>(_v) = _t->typeId; break;
        case 2: *reinterpret_cast< QString*>(_v) = _t->typeName(); break;
        default: break;
        }
    } else if (_c == QMetaObject::WriteProperty) {
        auto *_t = reinterpret_cast<PropertyValue *>(_o);
        (void)_t;
        void *_v = _a[0];
        switch (_id) {
        case 0:
            if (_t->value != *reinterpret_cast< QVariant*>(_v)) {
                _t->value = *reinterpret_cast< QVariant*>(_v);
            }
            break;
        case 1:
            if (_t->typeId != *reinterpret_cast< int*>(_v)) {
                _t->typeId = *reinterpret_cast< int*>(_v);
            }
            break;
        default: break;
        }
    } else if (_c == QMetaObject::ResetProperty) {
    }
#endif // QT_NO_PROPERTIES
    (void)_o;
    (void)_id;
    (void)_c;
    (void)_a;
}

QT_INIT_METAOBJECT const QMetaObject Tiled::PropertyValue::staticMetaObject = { {
    nullptr,
    qt_meta_stringdata_Tiled__PropertyValue.data,
    qt_meta_data_Tiled__PropertyValue,
    qt_static_metacall,
    nullptr,
    nullptr
} };

struct qt_meta_stringdata_Tiled__FilePath_t {
    QByteArrayData data[2];
    char stringdata0[20];
};
#define QT_MOC_LITERAL(idx, ofs, len) \
    Q_STATIC_BYTE_ARRAY_DATA_HEADER_INITIALIZER_WITH_OFFSET(len, \
    qptrdiff(offsetof(qt_meta_stringdata_Tiled__FilePath_t, stringdata0) + ofs \
        - idx * sizeof(QByteArrayData)) \
    )
static const qt_meta_stringdata_Tiled__FilePath_t qt_meta_stringdata_Tiled__FilePath = {
    {
QT_MOC_LITERAL(0, 0, 15), // "Tiled::FilePath"
QT_MOC_LITERAL(1, 16, 3) // "url"

    },
    "Tiled::FilePath\0url"
};
#undef QT_MOC_LITERAL

static const uint qt_meta_data_Tiled__FilePath[] = {

 // content:
       8,       // revision
       0,       // classname
       0,    0, // classinfo
       0,    0, // methods
       1,   14, // properties
       0,    0, // enums/sets
       0,    0, // constructors
       4,       // flags
       0,       // signalCount

 // properties: name, type, flags
       1, QMetaType::QUrl, 0x00095003,

       0        // eod
};

void Tiled::FilePath::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{

#ifndef QT_NO_PROPERTIES
    if (_c == QMetaObject::ReadProperty) {
        auto *_t = reinterpret_cast<FilePath *>(_o);
        (void)_t;
        void *_v = _a[0];
        switch (_id) {
        case 0: *reinterpret_cast< QUrl*>(_v) = _t->url; break;
        default: break;
        }
    } else if (_c == QMetaObject::WriteProperty) {
        auto *_t = reinterpret_cast<FilePath *>(_o);
        (void)_t;
        void *_v = _a[0];
        switch (_id) {
        case 0:
            if (_t->url != *reinterpret_cast< QUrl*>(_v)) {
                _t->url = *reinterpret_cast< QUrl*>(_v);
            }
            break;
        default: break;
        }
    } else if (_c == QMetaObject::ResetProperty) {
    }
#endif // QT_NO_PROPERTIES
    (void)_o;
    (void)_id;
    (void)_c;
    (void)_a;
}

QT_INIT_METAOBJECT const QMetaObject Tiled::FilePath::staticMetaObject = { {
    nullptr,
    qt_meta_stringdata_Tiled__FilePath.data,
    qt_meta_data_Tiled__FilePath,
    qt_static_metacall,
    nullptr,
    nullptr
} };

struct qt_meta_stringdata_Tiled__ObjectRef_t {
    QByteArrayData data[2];
    char stringdata0[20];
};
#define QT_MOC_LITERAL(idx, ofs, len) \
    Q_STATIC_BYTE_ARRAY_DATA_HEADER_INITIALIZER_WITH_OFFSET(len, \
    qptrdiff(offsetof(qt_meta_stringdata_Tiled__ObjectRef_t, stringdata0) + ofs \
        - idx * sizeof(QByteArrayData)) \
    )
static const qt_meta_stringdata_Tiled__ObjectRef_t qt_meta_stringdata_Tiled__ObjectRef = {
    {
QT_MOC_LITERAL(0, 0, 16), // "Tiled::ObjectRef"
QT_MOC_LITERAL(1, 17, 2) // "id"

    },
    "Tiled::ObjectRef\0id"
};
#undef QT_MOC_LITERAL

static const uint qt_meta_data_Tiled__ObjectRef[] = {

 // content:
       8,       // revision
       0,       // classname
       0,    0, // classinfo
       0,    0, // methods
       1,   14, // properties
       0,    0, // enums/sets
       0,    0, // constructors
       4,       // flags
       0,       // signalCount

 // properties: name, type, flags
       1, QMetaType::Int, 0x00095003,

       0        // eod
};

void Tiled::ObjectRef::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{

#ifndef QT_NO_PROPERTIES
    if (_c == QMetaObject::ReadProperty) {
        auto *_t = reinterpret_cast<ObjectRef *>(_o);
        (void)_t;
        void *_v = _a[0];
        switch (_id) {
        case 0: *reinterpret_cast< int*>(_v) = _t->id; break;
        default: break;
        }
    } else if (_c == QMetaObject::WriteProperty) {
        auto *_t = reinterpret_cast<ObjectRef *>(_o);
        (void)_t;
        void *_v = _a[0];
        switch (_id) {
        case 0:
            if (_t->id != *reinterpret_cast< int*>(_v)) {
                _t->id = *reinterpret_cast< int*>(_v);
            }
            break;
        default: break;
        }
    } else if (_c == QMetaObject::ResetProperty) {
    }
#endif // QT_NO_PROPERTIES
    (void)_o;
    (void)_id;
    (void)_c;
    (void)_a;
}

QT_INIT_METAOBJECT const QMetaObject Tiled::ObjectRef::staticMetaObject = { {
    nullptr,
    qt_meta_stringdata_Tiled__ObjectRef.data,
    qt_meta_data_Tiled__ObjectRef,
    qt_static_metacall,
    nullptr,
    nullptr
} };

QT_WARNING_POP
QT_END_MOC_NAMESPACE
